@@ -1,7 +1,8 @@
 package Pcore::Core::Exception;
 
 use Pcore -export => {    #
-    DEFAULT => [qw[croak cluck try catch]],
+    DEFAULT => [qw[croak cluck]],
+    TRY     => [qw[try catch]],
 };
 use Carp qw[];
 use Pcore::Core::Exception::Object;
@@ -152,19 +153,14 @@ sub cluck {
     return CORE::warn $e;
 }
 
-# create and throw new propagated exception
-sub propagate ($msg) {
-    return Pcore::Core::Exception::Object->new( $msg, level => 'ERROR', skip_frames => 1, trace => 1, propagated => 1 )->propagate;
-}
-
 # TRY / CATCH
 sub try ( $try, $catch = undef ) : prototype(&@) {
     my $wantarray = wantarray;
 
-    my @res;
-
     my $prev_error = $@;
 
+    my @res;
+
     my $failed = not eval {
 
         # we should create exception object manually, because __DIE__ will not work if try/catch will called from __DIE__ handler
@@ -201,14 +197,6 @@ sub try ( $try, $catch = undef ) : prototype(&@) {
                 $catch->($e);
             }
         }
-
-        if ( $e->is_propagated ) {
-
-            # clear $@ because handled propagated exception treat as not an error
-            $@ = q[];    ## no critic qw[Variables::RequireLocalizedPunctuationVars]
-
-            $e->propagate unless $e->_stop_propagate;
-        }
     }
 
     return $wantarray ? @res : $res[0];
@@ -225,9 +213,9 @@ sub catch ($code) : prototype(&) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 54, 67, 80, 99       | Variables::RequireInitializationForLocalVars - "local" variable not initialized                                |
+## |    3 | 55, 68, 81, 100      | Variables::RequireInitializationForLocalVars - "local" variable not initialized                                |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 56, 69, 82           | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
+## |    3 | 57, 70, 83           | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
